@@ -268,7 +268,7 @@ class PynagForm(AdagiosForm):
                 command_name__contains='')
             choices = [('', '')] + map(
                 lambda x: (x.command_name, x.command_name), all_objects)
-            field = forms.ChoiceField(choices=sorted(choices))
+            field = PynagChoiceField(choices=sorted(choices))
         # elif field_name == 'check_command':
         #    all_objects = Model.Command.objects.all
         #    choices = [('','')] + map(lambda x: (x.command_name, x.command_name), all_objects)
@@ -614,7 +614,11 @@ class BulkDeleteForm(BaseBulkForm):
     def delete(self):
         """ Deletes every object in the form """
         for i in self.changed_objects:
-            i.delete()
+            if i.object_type == 'host':
+                recursive = True
+            else:
+                recursive = False
+            i.delete(recursive=recursive)
 
 
 class CheckCommandForm(PynagForm):
