@@ -21,6 +21,8 @@ urlpatterns = patterns('adagios',
                        'status.views.status_servicegroups'),
                       (r'^/hosts/?$', 'status.views.hosts'),
                       (r'^/services/?$', 'status.views.services'),
+                      (r'^/test/services/?$', 'status.views.services_js'),
+                      (r'^/test/status_dt/?$', 'status.views.status_dt'),
                       (r'^/problems/?$', 'status.views.problems'),
                       (r'^/services_old/?$', 'status.views.status'),
                       (r'^/contacts/(?P<contact_name>.+)/?$',
@@ -38,6 +40,7 @@ urlpatterns = patterns('adagios',
                        #(r'^/hosts/(?P<host_name>.+)$', 'status.views.status_detail'),
                       (r'^/error/?$', 'status.views.error_page'),
                       (r'^/detail/?$', 'status.views.status_detail'),
+                      (r'^/(?P<object_type>.+).datatable/?$', 'status.views.datatable'),
 
                       (r'^/snippets/log/?$', 'status.views.snippets_log'),
 
